@@ -162,11 +162,29 @@ def count_num_examples(tfrecordfile, labeled = True):
 		cnt += 1
 	print(f"{tfrecordfile} contains {cnt} Examples")
 
+def get_labeled_tfrecord_format(dict, img_size):
+	global dictionary_labeled
+	global IMAGE_SIZE
+	
+	dictionary_labeled = dict
+	IMAGE_SIZE = img_size
+	
+def get_unlabeled_tfrecord_format(dict, img_size):
+	global dictionary_unlabeled
+	global IMAGE_SIZE
+	
+	dictionary_unlabeled = dict
+	IMAGE_SIZE = img_size
+	
+
 if __name__ == "__main__":
 	pass
 else:
+
 	import tensorflow as tf
 	if tf.__version__ == '2.2.0':
 		pass
 	else:
-		print("Error! Tensorflow version mismatch")
\ No newline at end of file
+		print("Error! Tensorflow version mismatch")
+		
+	
\ No newline at end of file
