@@ -1,4 +1,4 @@
-def get_models_training_report(models,tpu, n_class, traindata, steps_per_epoch, epochs, batch_size, val_data,  classification_model = 'default', freeze = False, input_shape = [512,512,3], activation = 'softmax', weights = "imagenet", optimizer = "adam", loss = "sparse_categorical_crossentropy", metrics = "sparse_categorical_accuracy", plot = False):
+def get_models_training_report(models,tpu, n_class, traindata, steps_per_epoch, epochs, batch_size, val_data,  classification_model = 'default', freeze = False, input_shape = [512,512,3], activation = 'softmax', weights = "imagenet", optimizer = "adam", loss = "sparse_categorical_crossentropy", metrics = "sparse_categorical_accuracy", callbacks = None, plot = False):
 	
 	import pandas as pd
 	import numpy as np
@@ -20,9 +20,9 @@ def get_models_training_report(models,tpu, n_class, traindata, steps_per_epoch,
 				model = create_model( freeze = freeze, input_shape = input_shape, activation = activation, weights = weights, optimizer = optimizer, loss = loss, metrics = metrics, classes = n_class, model_name = m, classification_model = classification_model)
 			else:
 				model = create_model( freeze = freeze, input_shape = input_shape, activation = activation, weights = weights, optimizer = optimizer, loss = loss, metrics = metrics , classes = n_class, model_name = m)
+				
 
-
-		history = model.fit(traindata, steps_per_epoch = steps_per_epoch, epochs = epochs,batch_size = batch_size, validation_data =  val_data, verbose = 0)
+		history = model.fit(traindata, steps_per_epoch = steps_per_epoch, epochs = epochs,batch_size = batch_size, validation_data =  val_data, callbacks = callbacks, verbose = 0)
 		tf.keras.backend.clear_session()
 		tf.compat.v1.reset_default_graph()
 		del model
